@@ -45,7 +45,6 @@ PATH=/bin:/usr/bin:/usr/local/bin:/usr/bin/X11:/usr/X11R6/bin
 
 # These should be set by the calling program into this env.
 # Most are not being used here and are merely listed for completeness.
-SW_CATALOG=""
 SW_CONTROL_DIRECTORY=""
 EXECDISP=${SW_CONTROL_TAG-"no_set_"}
 
@@ -572,9 +571,9 @@ check_files2() {
 }
 
 check_files_by_md5() {
-	csum=`${CAT} "${package_dir}"/catalog/dfiles/files | ${SED} -e 's@/$@@' | ${SORT} | ${MD5SUM}`
+	csum=`${CAT} "${package_dir}"/catalog/dfiles/files | ${SED} -e 's@/$@@' | ${SORT} | ${MD5SUM} | sed -e s/^'(stdin)= '//`
 	fsum=`find "${package_dir}" | ${SED} -e 's@/$@@' | ${SORT} | ${MD5SUM}`
-	# OLD slow way:  fsum=`${TAR} cf - ${package_dir} | ${TAR} tf - | ${SED} -e 's@/$@@' | ${SORT} | ${MD5SUM}`
+	# OLD slow way:  fsum=`${TAR} cf - ${package_dir} | ${TAR} tf - | ${SED} -e 's@/$@@' | ${SORT} | ${MD5SUM} | sed -e s/^'(stdin)= '//`
 	case "$csum" in
 		"") return 1
 		;;
@@ -655,7 +654,7 @@ check_digest_from_catalog_files() {
 		) | sed -e 's@/$@@' |
 	"${GREP}" -v ^"${package_dir}"/catalog
 	) | \
-		create_archive_stream "$tarcreateutil" | ${digest_program} | sed -e 's/ .*$//'`
+		create_archive_stream "$tarcreateutil" | ${digest_program} | sed -e 's/ .*$//' | sed -e s/^'(stdin)= '//`
 
 
 	psum=`cat "${digestfile}"`
@@ -723,6 +722,21 @@ RMDIR=`missing_which rmdir` || exit 1
 DIFF=`missing_which diff` || exit 1
 OPENSSL=`missing_which openssl 2>/dev/null`
 
+$DIFF --version 1>/dev/null  2>&1
+case $? in
+        0)
+        ;;
+        *)
+        case "`uname -s`" in
+                SunOS)
+# Why won't /usr/bin/diff on SunOS (Oracle Solaris 11.1 c.Mar2014) read correctly from a FIFO ?
+# It seems to be busted in the usage where the file is a FIFO (below) whilst GNU diff works OK.
+                        echo "$0: looking for a suitable version of diff on `uname -s` system" 1>&2
+                        DIFF=`missing_which /usr/gnu/bin/diff` || exit 1
+                ;;
+        esac
+esac
+
 if [ ! -f "$MD5SUM" ]; then
 	if [ -f "$OPENSSL" ]; then
 		MD5SUM="openssl md5"	
