@@ -1963,6 +1963,7 @@ swc_write_source_copy_script(GB * G,
 	STROB * to_devnull;
 	STROB * rootdir;
 	STROB * firstpath;
+	STROB * shell_lib_buf;
 	int vlv;
 
 	vlv = G->g_verboseG;
@@ -1997,6 +1998,7 @@ swc_write_source_copy_script(GB * G,
 	subsh2 = strob_open(10);
 	rootdir = strob_open(10);
 	firstpath = strob_open(10);
+	shell_lib_buf = strob_open(10);
 
 	if (vlv >= SWC_VERBOSE_SWIDB) {
 		strob_strcpy(set_vx, "set -vx\n");
@@ -2079,8 +2081,12 @@ swc_write_source_copy_script(GB * G,
 
 	strob_strcpy(buffer_new, "");
 
-	if (strcmp(get_opta(G->optaM, SW_E_swbis_shell_command), SWC_SHELL_KEY_DETECT) == 0) {
+	if (strcmp(get_opta(G->optaM, SW_E_swbis_shell_command), "detect") == 0) {
 		swpl_bashin_detect(buffer_new);
+	} else if (strcmp(get_opta(G->optaM, SW_E_swbis_shell_command), "posix") == 0) {
+		swpl_bashin_posixsh(buffer_new);
+	} else {
+		swpl_bashin_testsh(buffer_new, get_opta(G->optaM, SW_E_swbis_shell_command));
 	}
 
 	/* ret = swlib_writef(ofd, buffer,  */
@@ -2090,6 +2096,7 @@ swc_write_source_copy_script(GB * G,
 		"%s\n"
 		"%s"
 		"%s"
+		"%s\n"			/* function:  shls_check_for_gnu_tar */
 		"do_create=\"%s\"\n"
 		"multiple_source=\"%s\"\n"
 		"blocksize=\"%s\"\n"
@@ -2098,7 +2105,7 @@ swc_write_source_copy_script(GB * G,
 		"sourcepath=\"%s\"\n"
 		"sw_retval=0\n"
 		"sb__delaytime=%d\n"
-
+		"pax_write_command_key=\"%s\"\n"
 		CSHID
 		"if test -d \"$dirname\"; then\n"
 		"	cd \"$dirname\"\n"
@@ -2109,14 +2116,42 @@ swc_write_source_copy_script(GB * G,
 		"		\t\t%s\n"
 		"		\t\t%s\n"
 		"		\t\t%s\n"
+		"	# disable test for gnu tar when the selected tar command\n"
+		"	# is tar, this preserves ability to only use generic tar options\n"
+		"	# and avoid addition of the --format=pax string\n"
+		"		case \"${pax_write_command_key}\" in\n"
+		"		tar)\n"
+		"		( exit 1 ) # false\n"
+		"		;;\n"
+		"		*)\n"
+		"		shls_check_for_gnu_tar \n"
+		"		;;\n"
+		"		esac\n"
+		"		has_gnu_tar=$?\n"
 		"		case \"$multiple_source\" in\n"
 		"			\"\")\n"
-		"			%s \"$path\"\n"
-		"			sw_retval=$?\n"
+		"				case \"$has_gnu_tar\" in \n"
+		"				0)  # Yes, has gnu tar as tar\n"
+		"				tar cbf 1 - --format=pax \"$path\"\n"
+		"				sw_retval=$?\n"
+		"				;;\n"
+		"				*)\n"
+		"				%s \"$path\"\n"
+		"				sw_retval=$?\n"
+		"				;;\n"
+		"				esac\n"
 		"			;;\n"
 		"			x)\n"
-		"			%s %s\n"
-		"			sw_retval=$?\n"
+		"				case \"$has_gnu_tar\" in \n"
+		"				0)  # Yes, has gnu tar as tar\n"
+		"				tar cbf 1 - --format=pax %s\n"
+		"				sw_retval=$?\n"
+		"				;;\n"
+		"				*)\n"
+		"				%s %s\n"
+		"				sw_retval=$?\n"
+		"				;;\n"
+		"				esac\n"
 		"			;;\n"
 		"		esac\n"
 				"\t\t%s\n"
@@ -2165,6 +2200,7 @@ swc_write_source_copy_script(GB * G,
 		SEVENT(2, vlv, SW_SESSION_BEGINS, ""),
 		swicol_subshell_marks(subsh, "source", 'L', nhops, vlv),	
 		strob_str(set_vx),
+		shlib_get_function_text_by_name("shls_check_for_gnu_tar", shell_lib_buf, NULL),
 		(G->g_do_createM != 0) ? "x" : "",
 		(n_source_specs > 1) ? "x" : "",
 		blocksize,
@@ -2172,10 +2208,12 @@ swc_write_source_copy_script(GB * G,
 		spath,
 		sourcepath,
 		delaytime,
+		pax_write_command_key,
 		strob_str(opt2),
 		SEVENT(1, -1, SW_SOURCE_ACCESS_BEGINS, ""),
 		SEVENT(2, vlv, SW_SOURCE_ACCESS_BEGINS, ""),
 		pax_write_command,
+		mpath ? strob_str(mpath) : ".",
 		pax_write_command,
 		mpath ? strob_str(mpath) : ".",
 		SEVENT(2, vlv, SW_SOURCE_ACCESS_ENDS, "status=0"),
@@ -2224,6 +2262,7 @@ swc_write_source_copy_script(GB * G,
 	strob_close(subsh);
 	strob_close(subsh2);
 	strob_close(rootdir);
+	strob_close(shell_lib_buf);
 	if (mpath) strob_close(mpath);
 	/*
 	 * 0 is OK
