@@ -798,6 +798,10 @@ swconfig_write_source_copy_script2(GB * G,
 	strob_strcpy(buffer_new, "");
 	if (strcmp(get_opta(G->optaM, SW_E_swbis_shell_command), "detect") == 0) {
 		swpl_bashin_detect(buffer_new);
+	} else if (strcmp(get_opta(G->optaM, SW_E_swbis_shell_command), "posix") == 0) {
+		swpl_bashin_posixsh(buffer_new);
+	} else {
+		swpl_bashin_testsh(buffer_new, get_opta(G->optaM, SW_E_swbis_shell_command));
 	}
 
 	if (G->g_send_envM)
@@ -1142,8 +1146,8 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	SWI * swi;
 	SWGPG_VALIDATE * swgpg;
 	SWHEADER * isf_header;
-	CISF_PRODUCT * cisf_product;
-	SWI_PRODUCT * current_product;
+	CISF_PRODUCT * cisf_product = NULL;
+	SWI_PRODUCT * current_product = NULL;
  	
 	do_skip_entry = 0;
 	retval = 0;
