@@ -7,7 +7,7 @@
  * COPYING TERMS AND CONDITIONS
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -17,17 +17,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
-
-
 #ifndef swstructdef_19980513jhl_h
 #define swstructdef_19980513jhl_h
 
+extern "C" {
+#include "swuser_config.h"
+}
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <limits.h>
 
 extern "C" {
 #include "swsdflt.h"
@@ -121,7 +124,7 @@ class swstructdef
 	}
 
 	static char * get_default_value(void) {
-		return swsdflt_get_default_value(current_);
+		return swsdflt_get_default_value_by_ent(current_);
 	}
 };
 #endif
