@@ -221,7 +221,7 @@ class swExDistribution: public swExCat
 					// Emit the next directory.
 					//
 					strob_strcpy(tmp, getFormedControlPath(static_cast<char*>(NULL), 
-							(char*)(SW_CATALOG)));
+							(char*)(SW_A_catalog)));
 					
 					swlib_add_trailing_slash(tmp);
 					swExStruct_i::swexstruct_write_dir(strob_str(tmp), 
