@@ -7,7 +7,7 @@
 #include "swdefproduct.h"
 
 swDefProduct::swDefProduct(void): swDefinition() { }
-swDefProduct::swDefProduct(int level): swDefinition("product", level) { }
+swDefProduct::swDefProduct(int level): swDefinition(SW_A_product, level) { }
 
 swDefProduct::~swDefProduct(void){ }
 
