@@ -1050,7 +1050,7 @@ private: // ================================================================
 					ptmp[file_permsLength - 1] = '\0';
 					break;
 				case ownerE:
-					if (taru_get_user_by_uid(getuid(), usernamebuf) == 0) {
+					if (taru_get_tar_user_by_uid(getuid(), usernamebuf) == 0) {
 						copy_file_cell(fileArrayM, fileArrayWasSetM, ownerE, usernamebuf);
 					} else {
 						//
@@ -1060,7 +1060,7 @@ private: // ================================================================
 					}
 					break;
 				case groupE:
-					if (taru_get_group_by_gid(getgid(), usernamebuf) == 0) {
+					if (taru_get_tar_group_by_gid(getgid(), usernamebuf) == 0) {
 						copy_file_cell(fileArrayM, fileArrayWasSetM, groupE, usernamebuf);
 					} else {
 						//
@@ -2087,7 +2087,7 @@ private: // ================================================================
 		char * value = NULL;	
 		char * aux_value;
 		STROB  * val = strob_open(40);
-		int skip_amount;
+		int skip_amount = 0;
 		int error_code = 0;
 		int is_file_permissions_context = 0;
 		int did_umode = 0;
