@@ -66,6 +66,93 @@ add_if_vremoval(swDefinition * swdef, swMetaData * swmd, char * name)
 	return;
 }
 
+int swPackageFile::check_no_stat_optimization(swDefinition * swdef,
+				char fileArray[][file_permsLength],
+					int fileArrayWasSet[]) 
+{
+	int i;
+	int ret;
+
+	ret = 0;
+	for (i=0; i<lastE; i++) {
+		switch(i) {
+			//
+			//  These are the required attributes to
+			//  
+			case linksourceE:
+				if ( fileArrayWasSet[i] == 0 ) {
+					// Linksource Not set
+					if (fileArrayWasSet[typeE] && *fileArray[typeE] == SW_ITYPE_s) {
+						// Type is Link, Not OK
+						ret++;
+					} else {
+						// Type is not a Link, OK
+						;
+					}
+				}
+				break;	
+			case uidE:
+				if (fileArrayWasSet[i] == 0 && fileArrayWasSet[ownerE] == 0) ret++;
+				break;	
+			case gidE:
+				if (fileArrayWasSet[i] == 0 && fileArrayWasSet[groupE] == 0) ret++;
+				break;	
+			case modeE:
+			case typeE:
+				if (fileArrayWasSet[i] == 0) {
+					//
+					// Missing this attribute
+					//
+				       	ret++;
+					SWPACKAGEFILE_DEBUG2("test failed: [%d]", i);
+				}
+				break;	
+			case mtimeE:
+			case sizeE:
+			case groupE:
+			case ownerE:
+			case majorE:
+			case minorE:
+			case volaE:
+			case compE:
+			case cksumE:
+			case md5sumE:
+			case sha1sumE:
+			case sha512sumE:
+			case ctimeE:
+			case nlinkE:
+			case inoE:
+			case swbiE:
+			case umaskE:
+			default:
+				break;	
+		}
+	}
+
+	//
+	// 0  Means the PSF has all the file attributes, do optimize by not calling stat()
+	// >0 Means have to stat the file, too bad
+	//
+	if ( 
+		*fileArray[typeE] == SW_ITYPE_f ||
+		*fileArray[typeE] == SW_ITYPE_d ||
+		*fileArray[typeE] == SW_ITYPE_h ||
+		*fileArray[typeE] == SW_ITYPE_s ||
+		0
+	) {
+		//
+		// Restrict the optimizatin to regular files and directories and symlinks
+		//
+		return ret;
+	} else {
+		return 1;
+	}
+
+	// Never gets here
+	return 100;
+}
+
+
 int swPackageFile::initialize_file_stats_array(swDefinition * swdef,
 				char fileArray[][file_permsLength],
 					int fileArrayWasSet[]) 
@@ -89,6 +176,9 @@ int swPackageFile::initialize_file_stats_array(swDefinition * swdef,
 			case gidE:	// 7
 			case majorE:	// 16
 			case minorE:	// 15
+			case typeE:	// 0
+			case mtimeE:
+			case linksourceE:
 				//
 				//  Preserve these attributes that are
 				//  already set from the PSF file.
@@ -96,6 +186,12 @@ int swPackageFile::initialize_file_stats_array(swDefinition * swdef,
 				swmd = swdef->findAttribute(namesM[i]);
 				if (swmd) {
 					value = swmd->get_value((int*)(NULL));
+					if (i == linksourceE) {
+						if (strlen(value) >= file_permsLength -1) {
+							fprintf(stderr, "linksource too long: %s\n", value);
+							exit(1);
+						}
+					}
 					SWPACKAGEFILE_DEBUG3("INIT: setting attribute [%s] == [%s]", namesM[i], value);
 					::swlib_strncpy(fileArray[i], value, file_permsLength);
 					fileArrayWasSet[i] = 1;
@@ -106,14 +202,11 @@ int swPackageFile::initialize_file_stats_array(swDefinition * swdef,
 				break;
 			case volaE:
 			case compE:
-			case linksourceE:
 			case cksumE:
 			case md5sumE:
 			case sha1sumE:
 			case sha512sumE:
-			case typeE:
 			case ctimeE:
-			case mtimeE:
 			case nlinkE:
 			case inoE:
 			case swbiE:
@@ -163,7 +256,8 @@ swPackageFile::apply_file_stats(swDefinition * swdef, SWVARFS * swvarfs, char *s
 		//
 		// don't set the implicit file stats
 		//
-		SWPACKAGEFILE_DEBUG3("returning get_no_stat=[%d] storage_status=[%d]", swdef->get_no_stat(), swdef->get_storage_status());
+		SWPACKAGEFILE_DEBUG3("returning get_no_stat=[%d] storage_status=[%d]",
+				swdef->get_no_stat(), swdef->get_storage_status());
  		return 0;
 	}
 
@@ -187,11 +281,55 @@ swPackageFile::apply_file_stats(swDefinition * swdef, SWVARFS * swvarfs, char *s
 	
 	cksumflags = swdef->apply_cksum_policy_specialization(cksumflags);  // cksum are on for control_files.
 
-	SWPACKAGEFILE_DEBUG2("running stat on [%s]", source);
-	if (xFormat_u_lstat(source, &st) != 0) {
-		return -9991;
+	SWPACKAGEFILE_DEBUG2("running [%s]", source);
+
+	//
+	// Here is the main stat,  whether it is lstat for stat depends on the setting
+	// via swvarfs_set_stat_syscall(swvarfs, SWVARFS_VSTAT_STAT) e.g. or SWVARFS_VSTAT_LSTAT
+	//
+
+	if (    
+		check_no_stat_optimization(swdef, fileArray, fileArrayWasSet) == 0 &&
+		(
+		 	//
+			// Allow optimization on directories and sym links
+			//
+		 	(fileArrayWasSet[typeE] && *fileArray[typeE] == SW_ITYPE_d) ||
+		 	(fileArrayWasSet[typeE] && *fileArray[typeE] == SW_ITYPE_h) ||
+		 	(fileArrayWasSet[typeE] && *fileArray[typeE] == SW_ITYPE_s) 
+		)
+	) {	
+		//
+		// Good, got optimization permission, all the stats are set the the PSF
+		// Now, transfer them to &st, then keep running, the remainder of the
+		// function will be none-the-wiser.
+		//
+		SWPACKAGEFILE_DEBUG("avoiding stat()");
+		if (swMetaData::fileStats2statbuf(&st, fileArray, fileArrayWasSet) != 0) {
+			//
+			// failed for some reason.
+			// Fall back and run the real stat
+			//
+			SWPACKAGEFILE_DEBUG("optimization failed");
+			if (xFormat_u_lstat(source, &st) != 0) {
+				SWPACKAGEFILE_DEBUG("");
+				return -9980;
+			}
+		}
+	} else {
+		SWPACKAGEFILE_DEBUG("");
+		if (xFormat_u_lstat(source, &st) != 0) {
+			// FIXME  9991 is a special code with special meaning, should at least be an
+			// abtracted constant of some form.
+			return -9991;
+		}
 	}
-	
+
+	/********************************************************************************	
+	  ******************************************************************************
+		2014-03-29 (March 2014): the following code is obsolete atleast until I remember
+		the motivation for creating it in the first place. JL
+
 	swmd = swdef->findAttribute("type");
 
 	// JL if (swmd) swmd->write_fd(2);
@@ -242,6 +380,8 @@ swPackageFile::apply_file_stats(swDefinition * swdef, SWVARFS * swvarfs, char *s
 			}
 		}
 	}
+	*****************************************************************************************
+	**********************************************************************************************/
 
 	if (umask_value) {
 		SWPACKAGEFILE_DEBUG("");
