@@ -1,6 +1,6 @@
 /* rpmpsf.c - Routines for rpm-to-PSF file translation.
 
-   Copyright (C) 1998-2004 Jim Lowe
+   Copyright (C) 1998-2004,2014 Jim Lowe
    All Rights Reserved.
  
    COPYING TERMS AND CONDITIONS:
@@ -16,6 +16,8 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
+#define FILENEEDDEBUG 1
+#undef FILENEEDDEBUG
 
 #include "swuser_config.h"
 #include <stdio.h>
@@ -52,7 +54,6 @@
 static char * rpmpsf_make_dfiles (TOPSF * topsf, char * dfiles, int len);
 static char * de_quote_it (char * src);
 static void strip_newline(char *s);
-static int rpmpsf_get_rpm_filenames_tagvalue(Header h, int index, int *pcount, STROB * strb);
 
 #ifndef RPMPSF_RPM_HAS_FILELANGS
 #define RPMTAG_FILELANGS 1
@@ -245,6 +246,7 @@ rpmpsf_write_machine_name(Header h, int uxfio_ofd)
 	return 0;
 }
 
+
 int 
 rpmpsf_write_psf(TOPSF * topsf, int uxfio_ofd)
 {
@@ -431,8 +433,7 @@ rpmpsf_get_rpmtagvalue(Header h, int tagnumber, int index, int *pcount, STROB *
 
 	if (pcount) {
 		if (!rpmpsf_headerGetRawEntry(h, tagnumber, &type, (const void**)&da, pcount)) {
-			/* fprintf(stderr,"get_rpmtagvalue():headerGetRawEntry() failed for tag %d.\n", tagnumber);
-			*/
+			/* fprintf(stderr,"get_rpmtagvalue():headerGetRawEntry() failed for tag %d.\n", tagnumber); */
 			*pcount = -1;
 			return -1;
 		}
@@ -906,6 +907,7 @@ rpmpsf_write_fileset(TOPSF * topsf, int uxfio_ofd, char *fileset_tag, char * fil
 	STROB *strb1;
 	char * vendor_tag;
 
+	E_DEBUG("START");
 	if (!source_prefix) {
 		source_prefix=rpmpsf_make_package_prefix(topsf, (char*)NULL);
 	}
@@ -937,6 +939,7 @@ rpmpsf_write_fileset(TOPSF * topsf, int uxfio_ofd, char *fileset_tag, char * fil
 	vendor_tag = strdup(strob_str(strb1));
 
 	if (!strcmp(fileset_tag, RPMPSF_FILESET_SOURCE)) {
+		E_DEBUG("RPMPSF_FILESET_SOURCE");
 		
 		strcat(titlestring, " (pristine sources)");
 		ret += rpmpsf_write_rpm_attribute("title", titlestring, -1, 0, h, NULL, uxfio_ofd);
@@ -944,6 +947,7 @@ rpmpsf_write_fileset(TOPSF * topsf, int uxfio_ofd, char *fileset_tag, char * fil
 		ret += rpmpsf_write_psf_files(topsf, uxfio_ofd, SWPM_SRCFILESET_SOURCE, source_prefix, strb1);
 
 	} else if (!strcmp(fileset_tag, RPMPSF_FILESET_BUILD)) {
+		E_DEBUG("RPMPSF_FILESET_BUILD");
 		ret += rpmpsf_write_rpm_attribute("excluded_arch", NULL, RPMTAG_EXCLUDEARCH, -1, h, NULL, uxfio_ofd);
 		ret += rpmpsf_write_rpm_attribute("exclude_os", NULL, RPMTAG_EXCLUDEOS, -1, h, NULL, uxfio_ofd);
 		ret += rpmpsf_write_rpm_attribute("exclusive_arch", NULL, RPMTAG_EXCLUSIVEARCH, -1, h, NULL, uxfio_ofd);
@@ -962,6 +966,7 @@ rpmpsf_write_fileset(TOPSF * topsf, int uxfio_ofd, char *fileset_tag, char * fil
 		}
 
 	} else if (!strcmp(fileset_tag, RPMPSF_FILESET_PATCHES)) {
+		E_DEBUG("RPMPSF_FILESET_PATCHES");
 		strcat(titlestring, " (patches on the pristine sources)");
 		ret += rpmpsf_write_rpm_attribute("title", titlestring, -1, 0, h, NULL, uxfio_ofd);
 
@@ -969,6 +974,7 @@ rpmpsf_write_fileset(TOPSF * topsf, int uxfio_ofd, char *fileset_tag, char * fil
 
 		/* binary package, just one fileset */
 	} else {
+		E_DEBUG("BINARY");
 		if (swdef_filetype == 1 || swdef_filetype == 2 ) {
 			strncpy(titlestring, "The Packaged Files (the package distribution files)", 100);
 			ret += rpmpsf_write_rpm_attribute("title", titlestring, -1, 0, h, NULL, uxfio_ofd);
@@ -1002,10 +1008,13 @@ rpmpsf_write_fileset(TOPSF * topsf, int uxfio_ofd, char *fileset_tag, char * fil
 		}
 
 		if (swdef_filetype == 2 || swdef_filetype == 0) {
+			E_DEBUG("");
 			if (topsf->use_recursive_ == 0) {
+				E_DEBUG("entering rpmpsf_write_psf_files topsf->use_recursive_ == 0");
 				ret += rpmpsf_write_psf_files(topsf, uxfio_ofd, -1, source_prefix, strb1);
 			} else {
 				int nullfd = swbis_devnull_open("/dev/null", O_RDWR, 0);
+				E_DEBUG("topsf->use_recursive_ is true");
 				strob_strcpy(strb1, "directory .\nfile *\n");
 				uxfio_write(uxfio_ofd, (void*)strob_str(strb1), strob_strlen(strb1));
 				ret += rpmpsf_write_psf_files(topsf, nullfd, -1, source_prefix, strb1);
@@ -1371,6 +1380,33 @@ rpmpsf_write_changelogs(TOPSF * topsf, int uxfio_ofd)
 	return 0;
 }
 
+int
+rpmpsf_get_index_by_name(TOPSF * topsf, char * filename)
+{
+	Header h=topsf_get_rpmheader(topsf);
+	int numfiles, i;
+	char *typevector = NULL;
+	STROB * strb;
+
+	strb = strob_open(12);
+	E_DEBUG("");
+	if (rpmpsf_get_rpm_filenames_tagvalue(h, 0, &numfiles, NULL)) {
+		return -1;	
+	}
+	if (numfiles <= 0)
+		return -1;
+
+	for (i = 0; i < numfiles; i++) {
+		E_DEBUG3("numfiles=%d  i=%d", numfiles, i);
+		rpmpsf_get_rpm_filenames_tagvalue(h, i, (NULL), strb);
+		if (strcmp(strob_str(strb), filename) == 0) {
+			strob_close(strb);
+			return i;
+		}
+	}
+	return -1;
+}
+
 int
 rpmpsf_write_psf_files(TOPSF * topsf, int uxfio_ofd, int typeflag, char *source_prefix, STROB * strb)
 {
@@ -1378,16 +1414,25 @@ rpmpsf_write_psf_files(TOPSF * topsf, int uxfio_ofd, int typeflag, char *source_
 	int numfiles, i;
 	char *typevector = NULL;
 
+	numfiles = -1;
+	E_DEBUG("");
 	if (rpmpsf_get_rpm_filenames_tagvalue(h, 0, &numfiles, NULL)) {
-		return -1;	
+		E_DEBUG2("numfiles=%d", numfiles);
+		/* 
+ 		 * This is a normal path for a RPM with no files
+ 		 * therefore return zero
+ 		 */
+		return 0;	
 	}
 	if (numfiles <= 0)
 		return 0;
 
 	if (typeflag >= 0) {
+		E_DEBUG("classify");
 		if (classify_filelist(topsf, &typevector, numfiles)) return -1;
 	}
 	for (i = 0; i < numfiles; i++) {
+		E_DEBUG3("numfiles=%d  i=%d", numfiles, i);
 		if (typeflag < 0 || typeflag == typevector[i]) {
 			rpmpsf_write_file_psf(topsf, i, uxfio_ofd, source_prefix, strb);
 		}
@@ -1404,18 +1449,29 @@ rpmpsf_write_file_psf(TOPSF * topsf, int arrayindex, int uxfio_ofd, char *source
 	Header h=topsf_get_rpmheader(topsf);
 	char prefix[124], modeval[16], *pre, *sourcename, *link_s;
 	char * path;
+	char * bname;
 	int count, type, ret = 0, lmode;
 	int is_config_file;
 	int fileflag;
 	mode_t mode;
 
+	E_DEBUG("");
+	E_DEBUG2("source_prefix=[%s]", source_prefix);
+	E_DEBUG2("strb=[%s]", strob_str(strb));
+
 	is_config_file = 0;
+
+	/*
 	headerGetEntry(h, RPMTAG_DEFAULTPREFIX, &type, (void **) &pre, &count);
 	if (pre) {
 		swlib_strncpy(prefix, pre, sizeof(prefix));
 	} else {
 		swlib_strncpy(prefix, "", 10);
 	}
+	*/
+
+	swlib_strncpy(prefix, "", 10);
+
 	write_object_keyword("file", uxfio_ofd);
 
 	fileflag = 0;
@@ -1428,46 +1484,81 @@ rpmpsf_write_file_psf(TOPSF * topsf, int arrayindex, int uxfio_ofd, char *source
 	}
 	
 	ret += rpmpsf_get_rpm_filenames_tagvalue(h, arrayindex, (int *) NULL, strb);
-	path=swlib_strdup(strob_str(strb));
+	path = swlib_strdup(strob_str(strb));
 	rpmpsf_write_rpm_attribute("path", strob_str(strb), -1, -1, h, NULL, uxfio_ofd);
 
-	if (fileflag & RPMFILE_CONFIG) {
+	/*
+	 * Store the filename and set a value in the status array
+	 */
+
+	strar_add(topsf->header_namesM, strob_str(strb));
+	E_DEBUG3("Adding to header_namesM[%d] = [%s]", arrayindex, strob_str(strb));
+
+	strob_chr_index(topsf->file_status_arrayM,  arrayindex, TOPSF_FILE_STATUS_IN_HEADER);
+
+	E_DEBUG2("(VOLATILE TEST)Searching archive_namesM for [%s]", path);
+	if (topsf->rpmtag_default_prefixM) {
+		/* Remove prefix from path in order to compare to archive names
+		 */
+		bname = path;
+		if (strstr(bname, topsf->rpmtag_default_prefixM) == path) {
+			bname = bname + strlen(topsf->rpmtag_default_prefixM);
+			while (*bname == '/') bname++;
+		}
+	} else {
+		bname = path;
+	}
+
+	if (
+		fileflag & RPMFILE_CONFIG ||
+		topsf_search_list(topsf, topsf->archive_namesM, bname) < 0
+	) {
 		rpmpsf_write_rpm_attribute("is_volatile", "true", -1, -1, h, NULL, uxfio_ofd);
 	} else {
 		rpmpsf_write_rpm_attribute("is_volatile", "false", -1, -1, h, NULL, uxfio_ofd);
 	}
 
+	E_DEBUG2("source_prefix=[%s]", source_prefix);
 	sourcename=(char*)malloc(strlen(prefix) + strlen(source_prefix) + strlen(strob_str(strb)) + 20);	
 	
 	swlib_strncpy(sourcename, source_prefix, strlen(source_prefix) + 1);
+	E_DEBUG2("sourcename=[%s]", sourcename);
 	strncat(sourcename, prefix, strlen(prefix) + 1);
+	E_DEBUG2("sourcename=[%s]", sourcename);
 
 	if (strlen(sourcename) && sourcename[strlen(sourcename) - 1] != '/' &&
 	    *(strob_str(strb)) != '/')
 		strcat(sourcename, "/");
+	E_DEBUG2("sourcename=[%s]", sourcename);
 
 	strcat(sourcename, strob_str(strb));
-	if (strlen(sourcename) > 200) {
-		fprintf(stderr,"rpm2swpsf Warning: %s may be too long for a tar archive.\n", sourcename);
-	}
+	E_DEBUG2("sourcename=[%s]", sourcename);
 	
+	E_DEBUG("");
 	if (topsf->info_only_ == 0)
 		rpmpsf_write_rpm_attribute("source", sourcename, -1, -1, h, NULL, uxfio_ofd);
+	E_DEBUG3("attribute source: [%s] [%s]", strob_str(strb), sourcename);
 	topsf_add_fl_entry(topsf, strob_str(strb), sourcename, SWACFL_SRCCODE_ARCHIVE_STREAM);
 
 	ret += rpmpsf_get_rpmtagvalue(h, RPMTAG_FILEUSERNAME, arrayindex, (int *) NULL, strb);
 	rpmpsf_write_rpm_attribute("owner", strob_str(strb), -1, -1, h, NULL, uxfio_ofd);
 
+	E_DEBUG("");
 	ret += rpmpsf_get_rpmtagvalue(h, RPMTAG_FILEGROUPNAME, arrayindex, (int *) NULL, strb);
 	rpmpsf_write_rpm_attribute("group", strob_str(strb), -1, -1, h, NULL, uxfio_ofd);
 
 	ret += rpmpsf_get_rpmtagvalue(h, RPMTAG_FILEMTIMES, arrayindex, (int *) NULL, strb);
 	rpmpsf_write_rpm_attribute("mtime", strob_str(strb), -1, -1, h, NULL, uxfio_ofd);
+	E_DEBUG("");
 
 	ret += rpmpsf_get_rpmtagvalue(h, RPMTAG_FILEMODES, arrayindex, (int *) NULL, strb);
 	mode = (mode_t) swlib_atoi(strob_str(strb), NULL);
+	E_DEBUG2("rpmpsf_get_rpmtagvalue(h, RPMTAG_FILEMODES: mode=[%04o]", mode);
+
+
 	modeval[0] = (char) get_filetype(topsf, path, mode, &link_s);
 	modeval[1] = '\0';
+	E_DEBUG("");
 	if (link_s == NULL) {
 		ret += rpmpsf_get_rpmtagvalue(h, RPMTAG_FILELINKTOS, arrayindex, (int *) NULL, strb);
 		if (strlen(strob_str(strb)))
@@ -1477,18 +1568,43 @@ rpmpsf_write_file_psf(TOPSF * topsf, int arrayindex, int uxfio_ofd, char *source
 	}
 	swbis_free(path);
 
+	E_DEBUG("");
 	rpmpsf_write_rpm_attribute("type", modeval, -1, -1, h, NULL, uxfio_ofd);
+
+	if (*modeval == 's' /* symbolic link */) {
+		/* Make the permissions of sylinks be always 0777 */
+		mode = 0777;
+		if (topsf->verboseM > 1)
+			fprintf(stderr, "%s: setting perms 0777 for symlink in metadata: %s\n",
+							swlib_utilname_get(), path);
+	}
+	memset (modeval, '\0', sizeof(modeval));
+
+	/*
 	lmode = 0;
 	lmode |= (S_ISUID | S_ISGID | S_IRWXU | S_IRWXG | S_IRWXO);
+	*/
+
+	mode &= ~CP_IFMT;
+	E_DEBUG2("AFTER &= ~CP_IFMT  mode=[%04o]", mode);
+
+	/*
 	snprintf(modeval, 6, "%04o", mode & lmode);
+	*/	
+	snprintf(modeval, 6, "%04o", mode);
+	E_DEBUG2("MODEVAL=[%s]", modeval);
+
+
 	rpmpsf_write_rpm_attribute("mode", modeval, -1, -1, h, NULL, uxfio_ofd);
-	
+
+	E_DEBUG("");
 	if (topsf->info_only_) {
 		ret += rpmpsf_get_rpmtagvalue(h, RPMTAG_FILEMD5S, arrayindex, (int *) NULL, strb);
 		rpmpsf_write_rpm_attribute("md5sum", strob_str(strb), -1, -1, h, NULL, uxfio_ofd);
 		ret += rpmpsf_get_rpmtagvalue(h, RPMTAG_FILESIZES, arrayindex, (int *) NULL, strb);
 		rpmpsf_write_rpm_attribute("size", strob_str(strb), -1, -1, h, NULL, uxfio_ofd);
 	}
+	E_DEBUG("");
 
 	swbis_free(sourcename);	
 	return 0;
@@ -1898,7 +2014,6 @@ rpmpsf_write_out_tag(TOPSF *topsf, int ofd)
 	return -1;
 }
 
-static
 int
 rpmpsf_get_rpm_filenames_tagvalue(Header h, int index, int *pcount, STROB * strb)
 {
@@ -1906,14 +2021,22 @@ rpmpsf_get_rpm_filenames_tagvalue(Header h, int index, int *pcount, STROB * strb
 	char *p1;
 	char basename[124];
 	int ret;
-	
+
 	ret = rpmpsf_get_rpmtagvalue(h, RPMTAG_BASENAMES, index, pcount, strb);
-	if (ret) return ret;
+	if (ret) {
+		if (pcount == NULL) {
+			fprintf(stderr,"swbis: error from f_get_rpmtagvalue, tag=%d index=%d ret=%d.\n", RPMTAG_BASENAMES, index, ret); 
+		} else {
+			;
+			/* silence the warning when pcount is given */
+		}
+		return ret;
+	}
 	if (strb) {
 		strncpy(basename, strob_str(strb), sizeof(basename) - 1);
 		basename[sizeof(basename) - 1] = '\0';
 		if (rpmpsf_get_rpmtagvalue(h, RPMTAG_DIRINDEXES, index, pcount, strb)) {
-			fprintf(stderr,"get_rpm_filenames_tagvalue():rpmpsf_get_rpmtagvalue() failed for RPMTAG_DIRINDEXES, index=%d.\n", 
+			fprintf(stderr,"rpmpsf_get_rpm_filenames_tagvalue():rpmpsf_get_rpmtagvalue() failed for RPMTAG_DIRINDEXES, index=%d.\n", 
 					index);
 			return -1;
 		}
@@ -1927,9 +2050,13 @@ rpmpsf_get_rpm_filenames_tagvalue(Header h, int index, int *pcount, STROB * strb
 		strob_strcat(strb, basename);
 		while ((p1 = strstr(strob_str(strb), "//")) != (char *) (NULL))
 			memmove(p1, p1 + 1, strlen(p1));
+		E_DEBUG2("strb=[%s]", strob_str(strb));
 	}
 	return 0;
 #else
+	10MAR2014 This code should never happen, Eventually remove this test
+	from config.h.in and configure
+
 	int ret;
 	ret = rpmpsf_get_rpmtagvalue(h, RPMTAG_FILENAMES, index, pcount, strb);
 	return ret;
