@@ -93,5 +93,7 @@ int rpmpsf_get_psf_size(TOPSF * topsf);
 int rpm_tagstring_to_tagno (char * tagstring, struct_MI_headerTagTableEntry tags);
 int rpmpsf_write_out_tag(TOPSF *topsf, int ofd);
 int rpmpsf_get_rpmtag_length(TOPSF *topsf, char * tag);
+int rpmpsf_get_rpm_filenames_tagvalue(Header h, int index, int *pcount, STROB * strb);
+int rpmpsf_get_index_by_name(TOPSF * topsf, char * filename);
 
 #endif
