@@ -311,8 +311,8 @@ sumpPump(
 
 int
 swgp_stdioPump(int stdoutfd,      /* local stdout */
-		int outputpipefd, /* output on remote host */
-		int inputpipefd,  /* input on remote host */
+		int outputpipefd, /* output from remote host */
+		int inputpipefd,  /* input to remote host */
 		int stdinfd,      /* local stdin */ 
 		int opt_verbose, 
 		int opt_be_silent, 
@@ -678,8 +678,8 @@ swgp_close_all_fd(int start)
 		fprintf(stderr,
 		"%s: the maximum number of open file descriptors\n"
 		"%s: was determined to be %d.\n"
-		"%s: swbis requires more than this for its checks.\n"
-		"%s: against file descriptor leaks and its normal.\n"
+		"%s: swbis requires more than this for its checks\n"
+		"%s: against file descriptor leaks, and its normal\n"
 		"%s: operations.\n"
 		"%s"
 		,
