@@ -67,6 +67,25 @@ static uintmax_t * g_pstatbytes = NULL;
 static struct timespec * io_req = (struct timespec*)NULL;
 static int g_burst_adjust = 65000;
 
+static pid_t g_pax_header_pidG = 0;
+
+
+void
+swlib_set_pax_header_pid(pid_t n)
+{
+	g_pax_header_pidG = n;
+}
+
+pid_t
+swlib_get_pax_header_pid(void)
+{
+	if (g_pax_header_pidG == 0) {
+		g_pax_header_pidG = getpid();
+	}
+	return g_pax_header_pidG;
+}
+
+
 static
 ssize_t
 synct_i_no_null_write(int fd, char * buf, int sz)
@@ -113,16 +132,17 @@ synct_i_no_null_write(int fd, char * buf, int sz)
  	
 static
 ssize_t
-synct_i_read_block(SYNCT * synct, int fd, char * buf)
+synct_i_read_block(SYNCT * synct, ssize_t (*iof) (int, void *, size_t), int fd, char * buf)
 {
 	ssize_t ret;
 	E_DEBUG2("fd=%d", fd);
-	ret = uxfio_sfa_read(fd, buf, SWLIB_SYNCT_BLOCKSIZE);
+	ret = (iof) (fd, buf, SWLIB_SYNCT_BLOCKSIZE);
+	if (synct->debugfdM > 0) write(synct->debugfdM, buf, ret);
 	E_DEBUG("");
 	if (ret != SWLIB_SYNCT_BLOCKSIZE) {
-		fprintf(stderr, "%s: synct_i_read() error: ret=%d\n", swlib_utilname_get(), ret);
+		fprintf(stderr, "%s: synct_i_read_block() error: ret=%d\n", swlib_utilname_get(), (int)ret);
 		if (ret < 0) return -1;
-		return -2;
+		return -ret;
 	}
 	E_DEBUG("");
 	synct->countM++;
@@ -146,25 +166,41 @@ synct_check_for_possible_eof(SYNCT * synct)
 		(int)(pos - ibuf) < SWLIB_SYNCT_BLOCKSIZE &&
 		synct->mtM[i] != '\0'
 	) {
+
+	/* 
+	 *03MAR2014: BUG workaround:  for reason not known,
+	 * the TRAILER string has the final \r\n pair truncated
+	 * on rare oocasion. Hence to workaround, relax the requirement to only
+	 * look for TRAILER!!!\r\n not TRAILER!!!\r\n\r\n
+	 */     
+
 		if (*pos && *pos == synct->mtM[i]) {
 			/* so far so good */
 			E_DEBUG("finding trailer string, so far so good");
 			i++;
+		} else if (*pos == '\0' && i > 11) {
+			/*
+			 * Found mangled TRAILER!!!\r\n\0
+			 * Accept this as a bug work around.
+			 * This happens about 1% of the time and is the
+			 * source of program hangs when accessing the catalog.
+			 */
+			return SYNCT_EOF_CONDITION_2;
 		} else {
 			/* reset, bad match */
 			E_DEBUG("reset, bad match of trailer string");
-			return 0;
+			return SYNCT_EOF_CONDITION_0;
 		}
 		pos++;
 	}
 
 	if (synct->mtM[i] == '\0') {
-		/* Found the trailer string */
+		/* Found the entire trailer string */
 		E_DEBUG("found trailer");
-		return 1;
+		return SYNCT_EOF_CONDITION_1;
 	} else {
 		E_DEBUG("not found");
-		return 0;
+		return SYNCT_EOF_CONDITION_0;
 	}
 }
 
@@ -504,16 +540,30 @@ squash_trailing_char(char *path, char ch, int min_len)
 	}
 }
 
+
 int
 swlib_atoi(const char *nptr, int * result)
+{
+	return swlib_atoi2(nptr, (char**)(NULL), result);
+}
+
+int
+swlib_atoi2(const char *nptr, char ** fp_endptr, int * result)
 {
 	long ret;
 	char * endptr;
-	ret = strtol(nptr, &endptr, 10);
+	char ** a_endptr;
+	
+	if (fp_endptr)
+		a_endptr = fp_endptr;
+	else
+		a_endptr = &endptr;
+
+	ret = strtol(nptr, a_endptr, 10);
 
 	if (result) *result = 0;
 	if (
-		(endptr == nptr && ret == 0) ||
+		(*a_endptr == nptr && ret == 0) ||
 		((ret == LONG_MIN || ret == LONG_MAX) && errno == ERANGE)
 	) {
 		if (result) {
@@ -525,11 +575,18 @@ swlib_atoi(const char *nptr, int * result)
 }
 
 unsigned long int
-swlib_atoul(const char *nptr, int * result)
+swlib_atoul(const char *nptr, int * result, char ** fp_endptr)
 {
 	unsigned long int ret;
 	char * endptr;
-	ret = strtoul(nptr, &endptr, 10);
+	char ** p_endptr;
+
+	if (fp_endptr == NULL)
+		p_endptr = &endptr;
+	else
+		p_endptr = fp_endptr;
+
+	ret = strtoul(nptr, p_endptr, 10);
 
 	if (result) *result = 0;
 	if (
@@ -665,7 +722,7 @@ swlib_i_pipe_pump(int suction_fd, int discharge_fd,
 				}
 
 				if (obuf) {
-					strob_memcpy_at(obuf, buf, (size_t)(bytes), (size_t)byteswritten);
+					strob_memcpy_at(obuf, (size_t)byteswritten, buf, (size_t)(bytes));
 				}
 			}
 			E_DEBUG("");
@@ -719,7 +776,7 @@ swlib_i_pipe_pump(int suction_fd, int discharge_fd,
 				}
 
 				if (obuf) {
-					strob_memcpy_at(obuf, buf, (size_t)(bytes), (size_t)byteswritten);
+					strob_memcpy_at(obuf, (size_t)byteswritten, buf, (size_t)(bytes));
 				}
 
 				if (ibytes != bytes) {
@@ -1045,10 +1102,12 @@ swlib_toggle_leading_dotslash(char * mode, char * name, int *pflag)
 		if (strlen(name) < 2) {
 			*pflag = 0;
 			return;
-		}
-		if (strncmp(name,  "./", 2) == 0) {
+		} else if (strncmp(name,  "./", 2) == 0 && strlen(name) > 2) {
 			memmove(name, name+2, strlen(name)-1);
 			*pflag = 1;
+		} else {
+			*pflag = 0;
+			return;
 		}
 	} else {
 		if (*pflag) {
@@ -1575,6 +1634,8 @@ swlib_synct_create(void)
 	synct->tailM =  synct->bufM + SWLIB_SYNCT_BLOCKSIZE;
 	synct->countM = 0;
         synct->mtM = strdup(SWBIS_SYNCT_EOF);
+	synct->do_debugM = 0;
+	synct->debugfdM = -1; /*open("/tmp/swbis_synct.dump", O_RDWR|O_CREAT|O_APPEND|O_TRUNC, 0755);  */
 	return synct;
 }
 
@@ -1586,6 +1647,7 @@ swlib_synct_delete(SYNCT * synct)
 		fprintf(stderr, "%s: Warning: swlib_synct_delete() block count error: %d\n",
 			swlib_utilname_get(), synct->countM);
 	}
+	if (synct->debugfdM > 0) close(synct->debugfdM);
 	free(synct->mtM);
 	free(synct->bufM);
 	free(synct);
@@ -1618,6 +1680,7 @@ swlib_synct_read(SYNCT * synct, int fd, void * userbuf)
 	unsigned char * tbuf;
 	char * z;
 	int ret;
+	int tret;
 	int check_ret;
 
 	ibuf = synct->bufM;
@@ -1627,22 +1690,23 @@ swlib_synct_read(SYNCT * synct, int fd, void * userbuf)
 	   two times SWLIB_SYNCT_BLOCKSIZE */
 	
 	E_DEBUG2("fd = %d", fd);
-	ret = synct_i_read_block(synct, fd, (char*)ibuf);
+	ret = synct_i_read_block(synct, uxfio_sfa_read, fd, (char*)ibuf);
 	E_DEBUG2("synct_i_read_block() returned %d", ret);
 	if (ret < 0) return -1;
+	if (ret == 0) return 0;
 	check_ret = synct_check_for_possible_eof(synct);
 	E_DEBUG("");
-	if (check_ret == 0) {
+	if (check_ret == SYNCT_EOF_CONDITION_0) {
 		/* EOF not found */
 		memcpy(userbuf, ibuf, ret);
 		return (int)SWLIB_SYNCT_BLOCKSIZE;
 	} else {
 		/* EOF found */
-		/* read 1 more block which should be NUL
-		   if so its the trailer block therefore
+		/* read 1 more block which should be NULs.
+		   If so, its the trailer block therefore
 		   return 0 bytes to the user */
 		E_DEBUG2("fd = %d", fd);
-		ret = synct_i_read_block(synct, fd, (char*)tbuf);
+		ret = synct_i_read_block(synct, uxfio_sfa_read,  fd, (char*)tbuf);
 		if (ret < 0) return -2;
 		z = malloc((size_t)SWLIB_SYNCT_BLOCKSIZE);
 		memset(z, '\0', (size_t)SWLIB_SYNCT_BLOCKSIZE);
@@ -1650,9 +1714,20 @@ swlib_synct_read(SYNCT * synct, int fd, void * userbuf)
 		free(z);
 		if (ret == 0) {
 			/* really EOF */
+			if (check_ret == SYNCT_EOF_CONDITION_2) {
+				/* Bug workaround:
+				 * This condition occurs due to a mangled TRAILER!!!\r\n string and
+				 * seems to include two (or more??) extra blocks at the end of the pipe.
+				 * These need to be read and discarded to prevent
+				 * a block'ing read() and an apparent program hang.
+				 */
+				tret = 1;
+				while(tret > 0)
+					tret = synct_i_read_block(synct, timed_atomic_read5, fd, (char*)tbuf);
+			}
 			return 0;
 		} else {
-			/* we've been fooled !! */
+			/* we've been fooled !!, Note: this could be normal */
 			/* we now have read two (2) blocks which must be 
 			   returned to the user */
 			memcpy(userbuf, ibuf, SWLIB_SYNCT_BLOCKSIZE);
@@ -2081,13 +2156,23 @@ swlib_wait_on_all_pids(pid_t * pid, int num, int * status,
 		swlib_wait_on_all_pids_with_timeout(pid, num, status, flags, verbose_level, 0);
 }
 
+int
+swlib_wait_on_pid_with_timeout(pid_t pid, int * status, int flags, int verbose_level, int fp_tmo)
+{
+	pid_t apid;
+	int ret;
+	apid = pid;
+	ret = swlib_wait_on_all_pids_with_timeout(&apid, 1, status, flags, verbose_level, fp_tmo);
+	return ret;
+}
+
 int
 swlib_wait_on_all_pids_with_timeout(pid_t * pid, int num, int * status, 
 				int flags, int verbose_level, int fp_tmo)
 {
 	time_t now;
 	time_t start;
-	int wret;
+	int wret = -99;
 	int done = 0;
 	int i = 0;
 	int got_one = 0;
@@ -2109,8 +2194,6 @@ swlib_wait_on_all_pids_with_timeout(pid_t * pid, int num, int * status,
 
 	while (!done && (tmo == 0 || (int)(now - start) < tmo)) {
 		done = 1;
-		/* usleep(100000); */ /* Sleep 1/10th second, this greatly */
-				      /* improves performance on Cygwin    */
 		now = time(NULL);
 		E_DEBUG("");
 		for(i=0; i<num; i++) {
@@ -2158,7 +2241,7 @@ swlib_wait_on_all_pids_with_timeout(pid_t * pid, int num, int * status,
 		E_DEBUG("killing pids SIGKILL");
 		swlib_kill_all_pids(pid, num, SIGKILL, 3);
 	}
-	return status[num-1];
+	return wret; /* Now retval of last waitpid()*/   /* was status[num-1]; */
 }
 
 int 
@@ -2711,16 +2794,16 @@ swlib_apply_location(STROB * relocated_path, char * path, char * location, char
 	clean_location = swlib_return_no_leading(location);
 	clean_directory = swlib_return_no_leading(directory);
 
-	if (strlen(clean_directory) > 0) {
-		prefix = strstr(path, clean_directory);
-		if (prefix != NULL && prefix == path) {
-			 path += strlen(clean_directory);
+	if (strlen(clean_directory) > 0 && strlen(clean_path) > 0) {
+		prefix = strstr(clean_path, clean_directory);
+		if (prefix != NULL && prefix == clean_path) {
+			 clean_path += strlen(clean_directory);
 		}
 	} else {
 		;
 	}
 	strob_strcpy(relocated_path, location);
-	swlib_unix_dircat(relocated_path, path);
+	swlib_unix_dircat(relocated_path, clean_path);
 	return;
 }
 
@@ -2766,8 +2849,8 @@ swlib_append_synct_eof(STROB * buf)
 		") | dd ibs=%d obs=%d 2>/dev/null | dd ibs=%d obs=%d conv=sync 2>/dev/null |\n"
 		"	(\n"
 		"		dd bs=%d 2>/dev/null\n" 
-		"		( printf \"" CPIO_INBAND_EOA_FILENAME "\\r\\n\"\n" 
-		"		printf \"\\r\\n\" ) | dd ibs=%d obs=%d conv=sync 2>/dev/null\n"
+		"		( printf \"" CPIO_INBAND_EOA_FILENAME "\\r\\n\\r\\n\"\n" 
+		"		) | dd ibs=%d obs=%d conv=sync 2>/dev/null\n"
 		"	)\n"
 		") | dd ibs=%d obs=%d conv=sync 2>/dev/null\n",
 		SWLIB_SYNCT_BLOCKSIZE*3, SWLIB_SYNCT_BLOCKSIZE*3, SWLIB_SYNCT_BLOCKSIZE*2, SWLIB_SYNCT_BLOCKSIZE*2,
