@@ -48,7 +48,7 @@ squash_non_ascii_chars(unsigned char * ptr)
 		if (*s <= 127) {
 			;
 		} else {
-			memmove(s, s+1, strlen(s+1)+1);
+			memmove(s, s+1, (size_t)(strlen((char*)(s+1))+1));
 		}
 		s++;
 	}
