@@ -57,6 +57,9 @@ typedef struct {		/* Control script object 		*/
 	int sidM;		/* Id number 				*/
 	int resultM;		/* result				*/
 	SWI_FILE_MEMBER * afileM;	/* SWI_FILE_MEMBER 		*/
+	void * swi_xfileM;	/* (SWI_XFILE*) context			*/
+	int INFO_offsetM;	/* offset in swi_xfileM->info_headerM	*/
+			  	/* to the relevant software definition */
 } SWI_CONTROL_SCRIPT;
 
 typedef struct { 		/* List of SWI_CONTROL_SCRIPT		*/
@@ -71,7 +74,7 @@ void swi_control_script_delete(SWI_CONTROL_SCRIPT * s);
 SWI_CONTROL_SCRIPT * swi_control_script_create(void);
 void swi_add_script(SWI_SCRIPTS * thisisit, SWI_CONTROL_SCRIPT * v);
 char * swi_control_script_posix_result(SWI_CONTROL_SCRIPT * s);
-int swi_afile_write_script_cases(SWI_SCRIPTS * scripts, STROB * buf);
+int swi_afile_write_script_cases(SWI_SCRIPTS * scripts, STROB * buf, char * isc);
 char ** swi_afile_ieee_control_script_list(void);
 int swi_afile_is_ieee_control_script(char * pathname);
 int swi_control_script_get_return_code(char * posix_result);
