@@ -86,7 +86,7 @@ swi_xfile_delete(SWI_XFILE * s)
 	int index = 0;
 	SWI_FILE_MEMBER * file;
 
-	if (s->baseM.tagM) free(s->baseM.tagM);
+	if (s->baseM.b_tagM) free(s->baseM.b_tagM);
 	if (s->package_pathM) free(s->package_pathM);
 	if (s->control_dirM) free(s->control_dirM);
 	if (s->swi_scM) swi_scripts_delete(s->swi_scM);
@@ -124,6 +124,7 @@ swi_xfile_create(int type, SWHEADER * global_index_header, SWPATH_EX * current)
 		swi_vbase_init(s, SWI_I_TYPE_XFILE, global_index_header, NULL);
 	}
 
+	s->xfileM = (void*)s;
 	s->typeM = type;
 
 	s->package_pathM = NULL;
@@ -204,6 +205,24 @@ swi_xfile_get_control_script_by_path(SWI_XFILE * xfile, char * path)
 	return NULL;
 }
 
+SWI_CONTROL_SCRIPT * 
+swi_xfile_get_control_script_by_id(SWI_XFILE * xfile, int id)
+{
+	int index = 0;
+	SWI_SCRIPTS * sci = xfile->swi_scM;
+	SWI_CONTROL_SCRIPT ** scripts = sci->swi_coM;
+	while(*scripts && index < SWI_MAX_OBJ) {
+		if (id == (*scripts)->sidM) {
+			E_DEBUG2("found one, returning %p", (void*)(*scripts));
+			return (*scripts);
+		}
+		index++;
+		scripts++;
+	}
+	E_DEBUG("returning NULL");
+	return NULL;
+}
+
 SWI_CONTROL_SCRIPT * 
 swi_xfile_get_control_script_by_tag(SWI_XFILE * xfile, char * tag)
 {
@@ -213,7 +232,7 @@ swi_xfile_get_control_script_by_tag(SWI_XFILE * xfile, char * tag)
 	
 	E_DEBUG("ENTERING");
 	while(*scripts && index < SWI_MAX_OBJ) {
-		if (strcmp(tag, (*scripts)->baseM.tagM) == 0) {
+		if (strcmp(tag, (*scripts)->baseM.b_tagM) == 0) {
 			E_DEBUG2("found one, returning %p", (void*)(*scripts));
 			return (*scripts);
 		}
@@ -242,7 +261,7 @@ swi_examine_signature_blocks(SWI_XFILE * dfiles,
 	index = 0;
 	s = (SWI_FILE_MEMBER*)cplob_val(cplob, index);
 	while (s) {
-		f = strstr(s->pathnameM, "/signature");
+		f = strstr(s->pathnameM, "/" SW_A_signature);
 		if (f && *(f+10) == '\0') {
 			if (*sig_block_start == -1) *sig_block_start = s->header_start_offsetM;
 			*sig_block_end = s->data_start_offsetM + s->lenM;
