@@ -521,6 +521,10 @@ int taruib_clear_buffer(void)
 {
 	int ret;
 	ret = uxfio_write(g_taruib_gst_fdM, (void*)g_taruib_gst_bufferM, (size_t)g_taruib_gst_lenM);
+	if (ret < 0) {
+		fprintf(stderr, "swbis: module taruib: write error (fatal)\n");
+		exit(14);
+	}
 	g_taruib_gst_lenM -= ret;
 	
 	if (g_taruib_gst_lenM > 0) return -ret;
@@ -734,7 +738,7 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 				break;
 			} else {
 				E_DEBUG("");
-				fprintf(stderr, "internal error \n");
+				fprintf(stderr, "internal error: default else \n");
 				E_DEBUG("LEAVING");
 				return -1;
 			}
