@@ -58,12 +58,110 @@
 #define UINFILE_E_DEBUG3(arg, arg1, arg2)
 #endif /* UINFILENEEDDEBUG */
 
-#define UINFILE_I_INIT_READ_SIZE 124
+#define UINFILE_I_INIT_READ_SIZE 124 /* Must be greater then SARHDR which is 60 from ar.h  */
 #define UINFILE_I_TAR_BLOCK_SIZE 512
 
 #define MIN_PEEK_LEN	3
 #define LENGTH_OF_MAGIC	3  
 
+STROB *
+run_gpg_list_packets_command(unsigned char * xbuffer, int buffer_length)
+{
+	SHCMD * detect_gpg[2];
+	STROB * detect_text;
+	SHCMD * detect_command;
+	SHCMD * recompress_command;
+	int fd;
+	int ret;
+	
+	detect_text = strob_open(32);
+	/* Run this command
+	gpg --list-only --list-packets  --status-fd 1
+	*/
+	detect_command = shcmd_open();
+	shcmd_add_arg(detect_command, "gpg");
+	shcmd_add_arg(detect_command, "--list-only");
+	shcmd_add_arg(detect_command, "--list-packets");
+	shcmd_add_arg(detect_command, "--status-fd");
+	shcmd_add_arg(detect_command, "1");
+	shcmd_set_errfile(detect_command, "/dev/null");
+
+	detect_gpg[0] = detect_command;
+	detect_gpg[1] = (SHCMD*)NULL;
+	fd = swlib_open_memfd();
+	if (fd < 0) return NULL;
+	ret = uxfio_write(fd, (void*)xbuffer, (size_t)buffer_length);
+	if (ret <= 0) return NULL;
+	swlib_exec_filter(detect_gpg, fd, detect_text);
+	if (strob_strlen(detect_text) < 2) return NULL;
+	uxfio_close(fd);
+	shcmd_close(detect_command);
+	return detect_text;
+}
+
+static
+int
+is_gpg_data(void * gp)
+{
+	if (memcmp(gp, (void*)(UINFILE_MAGIC_gpg_sym), strlen(UINFILE_MAGIC_gpg_sym)) == 0) return 1;
+	if (memcmp(gp, (void*)(UINFILE_MAGIC_gpg_enc1), strlen(UINFILE_MAGIC_gpg_enc1)) == 0) return 2;
+	if (memcmp(gp, (void*)(UINFILE_MAGIC_gpg_enc2), strlen(UINFILE_MAGIC_gpg_enc2)) == 0) return 3;
+	return 0;
+}
+
+static
+int
+is_gpg_packet(unsigned char * gp)
+{
+/*
+	These tests are based on RFC4880
+*/
+	unsigned char b1;
+	unsigned char b2;
+	unsigned char packet_tag;
+
+	
+	b1 = *(gp+0);
+	b2 = *(gp+1);
+
+	if (!(b1 & (1 << 7)))
+		return 0;  /* Bit 7 is not set */
+
+	if (b1 & (1 << 6)) {
+		/* New Packet */
+		packet_tag = \
+			(b1 & (1 << 5))*32 + \
+			(b1 & (1 << 4))*16 + \
+			(b1 & (1 << 3))*8 + \
+			(b1 & (1 << 2))*4 + \
+			(b1 & (1 << 1))*2 + \
+			(b1 & (1 << 0))*1;
+	} else {
+		/* Old Packet */
+		packet_tag = \
+			(b1 & (1 << 5))*8 + \
+			(b1 & (1 << 4))*4 + \
+			(b1 & (1 << 3))*2 + \
+			(b1 & (1 << 2))*1;
+	}
+
+	if (packet_tag == 0) 
+		return 0;  /* Must not be a OpenPGP packet */
+
+	if (
+		packet_tag == 1 || /* 1        -- Public-Key Encrypted Session Key Packet */
+		packet_tag == 3 || /* 3        -- Symmetric-Key Encrypted Session Key Packet */
+		0
+	) {
+		return 1;
+	} else {
+		/* Nothing else is supported */
+		;
+	}	
+	return 0;
+}
+
+
 static
 int
 does_have_name_version(char * buf)
@@ -319,7 +417,7 @@ uinfile_handle_return(UINFORMAT * uinformat, int oflags, int uxfio_buffer_type)
 	UINFILE_E_DEBUG2("uxfio_buffer_type = %d", uxfio_buffer_type);
 
 	ahsStaticSetTarFilename(file_hdr, NULL);
-	ahsStaticSetTarLinkname(file_hdr, NULL);
+	ahsStaticSetPaxLinkname(file_hdr, NULL);
 
 	UINFILE_E_DEBUG2("HERE current_pos_=%d", (int)((uinformat)->current_pos_));
 	if (uxfio_lseek(uinformat->fdM, (off_t)(0), SEEK_SET) < 0) {
@@ -337,7 +435,7 @@ uinfile_handle_return(UINFORMAT * uinformat, int oflags, int uxfio_buffer_type)
 	UINFILE_E_DEBUG("HERE");
 	if (oflags & UINFILE_DETECT_FORCEUNIXFD && 
 				uinformat->fdM >= UXFIO_FD_MIN) {
-		UINFILE_E_DEBUG("HERE");
+		UINFILE_E_DEBUG("HERE: forking to make unix fd");
 		uxfio_fcntl(uinformat->fdM, UXFIO_F_ARM_AUTO_DISABLE, 1);
 		uinformat->fdM = swlib_fork_to_make_unixfd(uinformat->fdM,
 					&(uinformat->blockmask_),
@@ -348,7 +446,7 @@ uinfile_handle_return(UINFORMAT * uinformat, int oflags, int uxfio_buffer_type)
 					uinformat->fdM < UXFIO_FD_MIN)
 		)
 	{
-		UINFILE_E_DEBUG("HERE");
+		UINFILE_E_DEBUG("HERE: opendup with buffer type");
 		uinformat->fdM = uxfio_opendup(uinformat->fdM,
 							uxfio_buffer_type);
 		uxfio_fcntl(uinformat->fdM, UXFIO_F_SET_CANSEEK, 0);
@@ -361,7 +459,7 @@ uinfile_handle_return(UINFORMAT * uinformat, int oflags, int uxfio_buffer_type)
 		uinformat->fdM < UXFIO_FD_MIN )
 		) 
 	{
-		UINFILE_E_DEBUG("HERE");
+		UINFILE_E_DEBUG("HERE: 2:opendup with buffer type");
 		uinformat->fdM = uxfio_opendup(uinformat->fdM,
 							uxfio_buffer_type);
 		/*
@@ -373,14 +471,14 @@ uinfile_handle_return(UINFORMAT * uinformat, int oflags, int uxfio_buffer_type)
 		uinformat->fdM >= UXFIO_FD_MIN )
 		) 
 	{
-		UINFILE_E_DEBUG("HERE");
+		UINFILE_E_DEBUG("HERE: setting to buf type mem");
 		uxfio_fcntl(uinformat->fdM, UXFIO_F_SET_BUFTYPE,
 							UXFIO_BUFTYPE_MEM);
 		/*
 		UINFILE_E_DEBUG2("HERE\n%s", uxfio_dump_string(uinformat->fdM));
 		*/
 	} else {
-		UINFILE_E_DEBUG("HERE");
+		UINFILE_E_DEBUG("HERE: non of the above");
 		;
 	}
 	if (uinformat->fdM >= UXFIO_FD_MIN) {
@@ -429,6 +527,8 @@ uinfile_i_open(char *filename, int oflag, mode_t mode, UINFORMAT ** uinformat,
 	int deb_gz_offset = 0;
 	int val1;
 	int val2;
+	int do_recompress;
+	SHCMD * rezip;
 
 	/*
 	if (slack_name)
@@ -441,6 +541,7 @@ uinfile_i_open(char *filename, int oflag, mode_t mode, UINFORMAT ** uinformat,
 	dodebcontrol = oflags & UINFILE_DETECT_DEB_CONTROL;
 	dodebcontext = oflags & UINFILE_DETECT_DEB_CONTEXT;
 	dodebdata = oflags & UINFILE_DETECT_DEB_DATA;
+	do_recompress = oflags & UINFILE_DETECT_RECOMPRESS;
 
 	UINFILE_E_DEBUG2("dodebdata=%d", dodebdata);
 	UINFILE_E_DEBUG2("dodebcontext=%d", dodebcontext);
@@ -455,6 +556,7 @@ uinfile_i_open(char *filename, int oflag, mode_t mode, UINFORMAT ** uinformat,
 	
 	UINFILE_E_DEBUG2("forcetar=%d", forcetar);
 	UINFILE_E_DEBUG2("donative=%d", donative);
+	UINFILE_E_DEBUG2("dounrpminstall=%d", dounrpminstall);
 
 	if (dodebdata) {
 		;
@@ -466,7 +568,6 @@ uinfile_i_open(char *filename, int oflag, mode_t mode, UINFORMAT ** uinformat,
 		}
 		(*uinformat)->underlying_fdM = -1;
 		(*uinformat)->current_pos_ = 0;
-		(*uinformat)->zcat_cmdM = zcat_command;
 		(*uinformat)->file_hdrM=ahsStaticCreateFilehdr();
 		(*uinformat)->verboseM = 0;
 		(*uinformat)->has_leading_slashM = 0;
@@ -480,6 +581,7 @@ uinfile_i_open(char *filename, int oflag, mode_t mode, UINFORMAT ** uinformat,
 		(*uinformat)->deb_file_fd_ = -1;
 		(*uinformat)->n_deb_peeked_bytesM = 0;
 		(*uinformat)->pathname_prefixM = NULL;
+		(*uinformat)->recompress_commandsM = vplob_open();
 		if (slack_name)
 			(*uinformat)->slack_nameM = strdup(slack_name);
 		else
@@ -512,11 +614,13 @@ uinfile_i_open(char *filename, int oflag, mode_t mode, UINFORMAT ** uinformat,
 		UINFILE_E_DEBUG2("HERE dupfd = %d", dupfd);
 		
 		val1 = dupfd < UXFIO_FD_MIN ;
-		if (dupfd < UXFIO_FD_MIN)
+		if (dupfd < UXFIO_FD_MIN) {
+			UINFILE_E_DEBUG("HERE:  lseek\'ing on dupfd");
 			val2 = lseek(dupfd, 0L, SEEK_CUR);
-		else
+		} else {
 			val2 = -1;
-			
+		}
+	
 		if (val1 && val2 == -1) {
 			UINFILE_E_DEBUG3("HERE %d %s", errno, strerror(errno));
 			if (errno == ESPIPE){
@@ -622,9 +726,11 @@ LABEL_REREAD:
 	 * Identify the file type.
 	 */
 	if (doarb == 0) {
+		/* Peeked Length is  UINFILE_I_INIT_READ_SIZE */
 		if (0) {
 			;
 		} else if (dodebdata) {
+			/* Peeked length is (SARHDR + 1 + strlen(UINFILE_MAGIC_gz)) */
 			UINFILE_E_DEBUG("in dodebdata");
 			/* the ar header of data.tar.gz should be in xbuffer */
 			UINFILE_E_DEBUG("type: DEB (data)");
@@ -666,6 +772,7 @@ LABEL_REREAD:
 			(*uinformat)->current_pos_ = ret;
 			UINFILE_E_DEBUG2("current_pos_ is %d", ret);
 
+		/* End of dodebdata */
 		} else if (!memcmp(xbuffer, rpmmagic, 4) && !forcetar) {
 			UINFILE_E_DEBUG("type: RPM");
 			if (dounrpminstall == 0 && doieee == 0) {
@@ -750,13 +857,17 @@ LABEL_REREAD:
 							/* Unix compress */
 			UINFILE_E_DEBUG("type: COMPRESSED_Z");
 			(*uinformat)->ztypeM = UINFILE_COMPRESSED_Z;
+		} else if (is_gpg_data((void*)xbuffer)) {
+			UINFILE_E_DEBUG("type: GPG Encrypted");
+			(*uinformat)->ztypeM = UINFILE_COMPRESSED_GPG;
 		} else if (
 			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_armor,  strlen(UINFILE_MAGIC_gpg_armor)) == 0 ||
-			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_sym,  strlen(UINFILE_MAGIC_gpg_sym)) == 0 ||
-			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_enc1,  strlen(UINFILE_MAGIC_gpg_enc1)) == 0 ||
-			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_enc2,  strlen(UINFILE_MAGIC_gpg_enc2)) == 0 ||
+			is_gpg_packet((unsigned char*)xbuffer) ||	
 			0
 		) {
+			STROB * detect_text;
+			detect_text = run_gpg_list_packets_command((unsigned char*)xbuffer, peeklen);
+			if (detect_text) strob_close(detect_text);
 			UINFILE_E_DEBUG("type: GPG Encrypted");
 			(*uinformat)->ztypeM = UINFILE_COMPRESSED_GPG;
 		} else if ( donative == 0 &&
@@ -793,8 +904,8 @@ LABEL_REREAD:
 
 			deb_gz_offset = SARMAG + SARHDR + val1 + SARHDR;  /* val1 must be 4 */
 			if (peeklen < deb_gz_offset + LENGTH_OF_MAGIC) {
-				/* read further into the file */
 
+				/* read further into the file */
 				ret = taru_tape_buffered_read(refd, xbuffer+peeklen, deb_gz_offset+LENGTH_OF_MAGIC - peeklen);
 				if (ret != deb_gz_offset+LENGTH_OF_MAGIC - peeklen) {
 					fprintf(stderr,
@@ -802,6 +913,7 @@ LABEL_REREAD:
 						swlib_utilname_get(), peeklen,  ret);
 					return -1;
 				}
+				peeklen += ((deb_gz_offset+LENGTH_OF_MAGIC) - peeklen);
 			}
 			
 			/* look for gzmagic */
@@ -853,10 +965,13 @@ LABEL_REREAD:
 			UINFILE_E_DEBUG("");
 			tmp = strob_open(32);
 
+			/* read further into the file */
 			ret = taru_tape_buffered_read(refd, xbuffer+peeklen, sizeof(xbuffer) - peeklen);
 			if (ret != (int)sizeof(xbuffer) - (int)peeklen) {
 				return -1;
 			}
+			peeklen += (sizeof(xbuffer) - peeklen);
+
 			UINFILE_E_DEBUG2("ret=%d", ret);
 		
 			ret = taru_read_in_tar_header2((*uinformat)->taruM,
@@ -978,11 +1093,15 @@ LABEL_REREAD:
 			int xeoa;
 			UINFILE_E_DEBUG("type: binary_tarball");
 			UINFILE_E_DEBUG("");
+
+			/* read further into the file */
 			ret = taru_tape_buffered_read(refd, xbuffer+peeklen, sizeof(xbuffer) - peeklen);
 			if (ret != (int)sizeof(xbuffer) - (int)peeklen) {
 				return -1;
 			}
 			UINFILE_E_DEBUG2("ret=%d", ret);
+			peeklen += (sizeof(xbuffer) - peeklen);
+
 
 			/* This will save the first archive member which is "./", we need the
 			   permissions on this to create in the sw POSIX archive */
@@ -1098,8 +1217,13 @@ LABEL_REREAD:
 			if ((*uinformat)->ztypeM == UINFILE_COMPRESSED_NA) {
 				(*uinformat)->ztypeM = UINFILE_COMPRESSED_NOT;
 			}
-			if (taru_tape_buffered_read(refd,
-				xbuffer + peeklen, 512 - peeklen) != (512 - peeklen)) return -1;
+
+			/* Read further into the file */
+			if (taru_tape_buffered_read(refd, xbuffer+peeklen,
+					512 - peeklen) != (512 - peeklen))
+				return -1;
+			peeklen += (512 - peeklen);
+
 
 			tar_hdr = (struct tar_header *)xbuffer;
 			taru_otoul(tar_hdr->chksum, &tar_hdr_sum);
@@ -1164,6 +1288,7 @@ LABEL_REREAD:
 			/* } */ /* arbitrary tar */
 		}
 	} else { /* doarb */
+		/* Peeked Length is  MIN_PEEK_LEN */
 		UINFILE_E_DEBUG("");
 		if (!memcmp(xbuffer, (void *) gzmagic, 2)) {
 						/* gzipped compression */
@@ -1185,13 +1310,18 @@ LABEL_REREAD:
 							/* Unix compress */
 			UINFILE_E_DEBUG("");
 			(*uinformat)->ztypeM = UINFILE_COMPRESSED_Z;
+		} else if (is_gpg_data((void*)xbuffer)) {
+			UINFILE_E_DEBUG("type: GPG Encrypted");
+			(*uinformat)->ztypeM = UINFILE_COMPRESSED_GPG;
 		} else if (
 			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_armor,  strlen(UINFILE_MAGIC_gpg_armor)) == 0 ||
-			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_sym,  strlen(UINFILE_MAGIC_gpg_sym)) == 0 ||
-			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_enc1,  strlen(UINFILE_MAGIC_gpg_enc1)) == 0 ||
-			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_enc2,  strlen(UINFILE_MAGIC_gpg_enc2)) == 0 ||
+			is_gpg_packet((unsigned char*)xbuffer) ||	
 			0
 		) {
+			UINFILE_E_DEBUG("type: GPG Encrypted");
+			STROB * detect_text;
+			detect_text = run_gpg_list_packets_command((unsigned char*)xbuffer, peeklen);
+			if (detect_text) strob_close(detect_text);
 			UINFILE_E_DEBUG("type: GPG Encrypted");
 			(*uinformat)->ztypeM = UINFILE_COMPRESSED_GPG;
 		} else {
@@ -1226,11 +1356,22 @@ LABEL_REREAD:
 			return -1;
 		}
 	}
-	if (zcat_command && (*uinformat)->ztypeM == UINFILE_COMPRESSED_Z) {
+	if ((*uinformat)->ztypeM == UINFILE_COMPRESSED_Z) {
 		unzip[0] = shcmd_open();
 		shcmd_add_arg(unzip[0], "compress");
 		shcmd_add_arg(unzip[0], "-cd");
+		if (do_recompress) {
+			UINFILE_E_DEBUG("recompress: compress");
+			rezip = shcmd_open();
+			UINFILE_E_DEBUG("recompress: xz");
+			shcmd_add_arg(rezip, "compress");
+			shcmd_add_arg(rezip, "-c");
+			vplob_add((*uinformat)->recompress_commandsM, rezip);
+		}
 	} else if ((*uinformat)->ztypeM == UINFILE_COMPRESSED_DEB) {
+
+		/* Do not record the recompress_commands for DEB packages */
+
 		UINFILE_E_DEBUG("in deb code");
 		if (memcmp(((char*)(xbuffer)) + deb_gz_offset,
 				gzmagic, LENGTH_OF_MAGIC) == 0) {
@@ -1250,6 +1391,11 @@ LABEL_REREAD:
 			unzip[0] = shcmd_open();
 			shcmd_add_arg(unzip[0], "lzma");
 			shcmd_add_arg(unzip[0], "-d");
+		} else if (memcmp(((char*)(xbuffer)) + deb_gz_offset,
+				xzmamagic, LENGTH_OF_MAGIC) == 0) {
+			unzip[0] = shcmd_open();
+			shcmd_add_arg(unzip[0], "xz");
+			shcmd_add_arg(unzip[0], "-d");
 		} else {
 			/*
 			 * error, the compressed magic not found at the expected offset
@@ -1257,7 +1403,6 @@ LABEL_REREAD:
 			fprintf(stderr, "%s: unsupported compression in a .deb file %s: at line %d\n", swlib_utilname_get(), __FILE__, __LINE__);
 			return -1;
 		} 
-
 		/*
 		 * The file is now positioned at the control.tar.gz file
 		 */
@@ -1268,21 +1413,60 @@ LABEL_REREAD:
 		unzip[0] = shcmd_open();
 		shcmd_add_arg(unzip[0], "gzip");
 		shcmd_add_arg(unzip[0], "-d");
+		if (do_recompress) {
+			UINFILE_E_DEBUG("recompress: gzip");
+			rezip = shcmd_open();
+			shcmd_set_exec_function(rezip, "execvp");
+			shcmd_add_arg(rezip, "gzip");
+			shcmd_add_arg(rezip, "-c");
+			shcmd_add_arg(rezip, "-9");
+			vplob_add((*uinformat)->recompress_commandsM, rezip);
+		}
 	} else if ((*uinformat)->ztypeM == UINFILE_COMPRESSED_BZ2) {
 		UINFILE_E_DEBUG("in bzip code");
 		unzip[0] = shcmd_open();
 		shcmd_add_arg(unzip[0], "bzip2");
 		shcmd_add_arg(unzip[0], "-d");
+
+		if (do_recompress) {
+			UINFILE_E_DEBUG("recompress: bzip2");
+			rezip = shcmd_open();
+			shcmd_set_exec_function(rezip, "execvp");
+			shcmd_add_arg(rezip, "bzip2");
+			shcmd_add_arg(rezip, "-c");
+			vplob_add((*uinformat)->recompress_commandsM, rezip);
+		}
 	} else if ((*uinformat)->ztypeM == UINFILE_COMPRESSED_LZMA) {
 		UINFILE_E_DEBUG("in lzma code");
 		unzip[0] = shcmd_open();
 		shcmd_add_arg(unzip[0], "lzma");
 		shcmd_add_arg(unzip[0], "-d");
+
+		if (do_recompress) {
+			UINFILE_E_DEBUG("recompress: lzma");
+			rezip = shcmd_open();
+			shcmd_set_exec_function(rezip, "execvp");
+			shcmd_add_arg(rezip, "lzma");
+			shcmd_add_arg(rezip, "-z");
+			shcmd_add_arg(rezip, "-c");
+			vplob_add((*uinformat)->recompress_commandsM, rezip);
+		}
 	} else if ((*uinformat)->ztypeM == UINFILE_COMPRESSED_XZ) {
 		UINFILE_E_DEBUG("in xz code");
 		unzip[0] = shcmd_open();
 		shcmd_add_arg(unzip[0], "xz");
 		shcmd_add_arg(unzip[0], "-d");
+
+		if (do_recompress) {
+			rezip = shcmd_open();
+			UINFILE_E_DEBUG("recompress: xz");
+			shcmd_set_exec_function(rezip, "execvp");
+			shcmd_add_arg(rezip, "xz");
+			shcmd_add_arg(rezip, "-z");
+			shcmd_add_arg(rezip, "-c");
+			vplob_add((*uinformat)->recompress_commandsM, rezip);
+		}
+
 	} else if ((*uinformat)->ztypeM == UINFILE_COMPRESSED_GPG) {
 		UINFILE_E_DEBUG("in gpg code");
 		unzip[0] = shcmd_open();
@@ -1300,8 +1484,6 @@ LABEL_REREAD:
 		shcmd_add_arg(unzip[0], "ustar");
 	} else if ((*uinformat)->ztypeM == UINFILE_COMPRESSED_SLACK_WITH_NAME) {
 		UINFILE_E_DEBUG("in UINFILE_COMPRESSED_SLACK_WITH_NAME");
-		/* fprintf(stderr, "JL you're a SLACKER: %s:%s at line %d\n", __FILE__, __FUNCTION__, __LINE__); */
-		/* shcmd_add_arg(unzip[0], "swbis"); */
 		unzip[0] = shcmd_open();
 		shcmd_add_arg(unzip[0], SWBISBINDIR "/swpackage");
 		shcmd_add_arg(unzip[0], "--to-swbis");
@@ -1317,17 +1499,6 @@ LABEL_REREAD:
 		unzip[0] = shcmd_open();
 		shcmd_add_arg(unzip[0], SWBISBINDIR "/swpackage");
 		shcmd_add_arg(unzip[0], "--to-swbis");
-		/*
-		shcmd_add_arg(unzip[0], "--no-defaults");
-		shcmd_add_arg(unzip[0], "-W");
-		shcmd_add_arg(unzip[0], "files");
-		shcmd_add_arg(unzip[0], "-W");
-		shcmd_add_arg(unzip[0], "file-digests");
-		shcmd_add_arg(unzip[0], "-W");
-		shcmd_add_arg(unzip[0], "archive-digests");
-		shcmd_add_arg(unzip[0], "-W");
-		shcmd_add_arg(unzip[0], "dummy-sign");
-		*/
 		shcmd_add_arg(unzip[0], "--catalog-owner=0");
 		shcmd_add_arg(unzip[0], "--catalog-group=0");
 		shcmd_add_arg(unzip[0], "@-");
@@ -1753,3 +1924,19 @@ uinfile_close(UINFORMAT * uinformat)
 	UINFILE_E_DEBUG("");
 	return ret;
 }
+
+SHCMD **
+uinfile_get_recompress_vector(UINFORMAT * uinformat)
+{
+	VPLOB * vplob = uinformat->recompress_commandsM;
+
+	if (vplob_get_nstore(vplob) == 0) {
+		/* Not recompressing */
+		return NULL;
+	} else {
+		SHCMD ** ret;
+		ret = (SHCMD**)vplob_get_list(vplob);
+		return ret;
+	}
+	return NULL;
+}
