@@ -1,8 +1,15 @@
+#include "swuser_config.h"
 #include <stdio.h>
 #include <stdlib.h>
+#include <limits.h>
+#include "swlib.h"
+#include "xformat.h"
+#include "strtoint.h"
+#include "swmain.h"  /* this file should be included by the main program file */
+#include "inttostr.h"
+#include "config_remains.h" 
 #include "uxfio.h"
 
-
 int main(int argc, char ** argv)
 {
 	int fd1;
@@ -17,6 +24,7 @@ int main(int argc, char ** argv)
 
 	swlib_pipe_pump(fd2, fd1);
 
+	/* uxfio_fsync(fd2); */
 	uxfio_close(fd2);
 	uxfio_close(fd1);
 	exit(0);
