@@ -4,7 +4,8 @@
 #include <string.h>
 #include <unistd.h>
 #include <typeinfo>
-#include "stream_config.h"
+
+#include "xstream_config.h"
 
 extern "C" {
 #include "swlib.h"
