@@ -15,7 +15,7 @@ TOUCH=`which touch`
 . tests/regression/testlib.sh
 
 bin/testforgnutar.sh || exit 2
-bin/testforgnupg.sh || exit 2
+# bin/testforgnupg.sh || exit 2
 
 echo "$0: Testing storage section aggreement with GNU tar" 1>&2
 echo "$0: Directory: "`pwd` 1>&2
